| long_stars-class | R Documentation |
An S4 class to hold a multi-dimensional array and a data.frame with a many-to-one relationship.
## S4 method for signature 'long_stars'
values(x)
## S4 replacement method for signature 'long_stars'
values(x) <- value
## S4 method for signature 'long_stars'
locations(x)
## S4 replacement method for signature 'long_stars'
locations(x) <- value
x |
An object |
value |
A replacement value |
The predictions slot will have at least 1 dimension, the
first of which must be named idx and is identical to the row
dimension of locations.
values(long_stars): Get values in multi-dimensional array
values(long_stars) <- value: Set values in multi-dimensional array
locations(long_stars): Get locations
locations(long_stars) <- value: Set locations
predictionsA stars object.
locationsAn sf object with at least a time column and point geometries.
Other starve_classes:
TMB_out-class,
dag-class,
observation_parameters-class,
observations-class,
parameters-class,
process-class,
process_parameters-class,
settings-class,
starve-class,
tracing-class
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.