| observation_parameters-class | R Documentation |
An S4 class to hold observation parameters for a starve model.
## S4 method for signature 'observation_parameters'
response_distribution(x)
## S4 replacement method for signature 'observation_parameters'
response_distribution(x) <- value
## S4 method for signature 'observation_parameters'
response_parameters(x)
## S4 replacement method for signature 'observation_parameters'
response_parameters(x) <- value
## S4 method for signature 'observation_parameters'
link_function(x)
## S4 replacement method for signature 'observation_parameters'
link_function(x) <- value
## S4 method for signature 'observation_parameters'
fixed_effects(x)
## S4 replacement method for signature 'observation_parameters'
fixed_effects(x) <- value
x |
An object |
value |
A replacement value |
response_distribution(observation_parameters): Get response distribution(s)
response_distribution(observation_parameters) <- value: Get/set response distribution(s). Run
get_starve_distributions("distribution") for valid options. Setting the
the response distribution also overwrites the response parameters and
link function(s).
response_parameters(observation_parameters): Get response distribution parameters
response_parameters(observation_parameters) <- value: Set response distribution parameters
link_function(observation_parameters): Get link function(s)
link_function(observation_parameters) <- value: set link function(s). Run
get_starve_distributions("link") for valid options.
fixed_effects(observation_parameters): Get fixed effect parameters
fixed_effects(observation_parameters) <- value: Set fixed effect parameters
response_distributionThe response distribution(s), must be one from get_starve_distributions("distribution").
response_parametersA list containing a data.frame of response distribution parameters for each response variable.
link_functionThe link function(s), must be one from get_starve_distributions("link").
fixed_effectsA list containing a data.frame of fixed effect parameters for each response variable.
Other starve_classes:
TMB_out-class,
dag-class,
long_stars-class,
observations-class,
parameters-class,
process-class,
process_parameters-class,
settings-class,
starve-class,
tracing-class
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.