| observations-class | R Documentation |
An S4 class to hold the observation information for a starve model.
## S4 method for signature 'observations'
dat(x)
## S4 replacement method for signature 'observations'
dat(x) <- value
## S4 method for signature 'observations'
data_predictions(x)
## S4 replacement method for signature 'observations'
data_predictions(x) <- value
## S4 method for signature 'observations'
parameters(x)
## S4 replacement method for signature 'observations,ANY'
parameters(x) <- value
x |
An object |
value |
A replacement value |
dat(observations): Get data, including response variables,
time indices, locations, covariates, etc.
dat(observations) <- value: Set data. Warning: if you want to add new
rows you must give each additional row a value in the graph_idx column,
or create a new object from scratch.
data_predictions(observations): Get data_predictions, a long_stars object
with the data (see dat) and associated random effect predictions.
data_predictions(observations) <- value: Set data predictions
parameters(observations): Get parameters as an
observation_parameters object.
parameters(x = observations) <- value: Set parameters using a new
observation_parameters object. Not the recommended way to
modify specific parameter values, instead see vignette("starve-tour").
data_predictionsA long_stars object for the data.
transient_graphA dag object describing the dependence of the data on the process.
parametersAn object of class observation_parameters.
strv_prepare
Other starve_classes:
TMB_out-class,
dag-class,
long_stars-class,
observation_parameters-class,
parameters-class,
process-class,
process_parameters-class,
settings-class,
starve-class,
tracing-class
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.