| process-class | R Documentation |
An S4 class to hold the process information for a starve model.
## S4 method for signature 'process'
time_effects(x)
## S4 replacement method for signature 'process'
time_effects(x) <- value
## S4 method for signature 'process'
pg_re(x)
## S4 replacement method for signature 'process'
pg_re(x) <- value
## S4 method for signature 'process'
tg_re(x)
## S4 replacement method for signature 'process'
tg_re(x) <- value
## S4 method for signature 'process'
persistent_graph(x)
## S4 method for signature 'process'
transient_graph(x)
## S4 method for signature 'process'
parameters(x)
## S4 replacement method for signature 'process,ANY'
parameters(x) <- value
## S4 method for signature 'process'
random_effects(x)
x |
An object |
value |
A replacement value |
time_effects(process): Get temporal random effects
time_effects(process) <- value: Set temporal random effects
pg_re(process): Get spatio-temporal random effects for persistent
graph
pg_re(process) <- value: Set spatio-temporal random effects for persistent
graph
tg_re(process): Get spatio-temporal random effects for transient
graph
tg_re(process) <- value: Set spatio-temporal random effects for transient
graph
persistent_graph(process): Get persistent graph
transient_graph(process): Get transient graph
parameters(process): Get parameters as a process_parameters object
parameters(x = process) <- value: Set parameters using a new process_parameters
object. Not the recommended way to modify specific parameter values,
instead see vignette("starve-tour").
random_effects(process): Get list containing the persistent graph random
effects and the transient graph random effects.
time_effectsA stars object containing temporal random effects
random_effectsA stars object containing spatio-temporal random effects.
persistent_graphA dag object describing the dependence graph of the process.
parametersAn object of class process_parameters.
strv_prepare
Other starve_classes:
TMB_out-class,
dag-class,
long_stars-class,
observation_parameters-class,
observations-class,
parameters-class,
process_parameters-class,
settings-class,
starve-class,
tracing-class
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.