| starve-class | R Documentation |
An S4 class describing a starve model.
## S4 method for signature 'starve'
settings(x)
## S4 method for signature 'starve'
tracing(x)
## S4 method for signature 'starve'
time_effects(x)
## S4 replacement method for signature 'starve'
time_effects(x) <- value
## S4 method for signature 'starve'
pg_re(x)
## S4 replacement method for signature 'starve'
pg_re(x) <- value
## S4 method for signature 'starve'
tg_re(x)
## S4 replacement method for signature 'starve'
tg_re(x) <- value
## S4 method for signature 'starve'
random_effects(x)
## S4 method for signature 'starve'
persistent_graph(x)
## S4 method for signature 'starve'
transient_graph(x)
## S4 method for signature 'starve'
graph(x)
## S4 method for signature 'starve'
covariance_function(x)
## S4 replacement method for signature 'starve'
covariance_function(x) <- value
## S4 method for signature 'starve'
space_parameters(x)
## S4 replacement method for signature 'starve'
space_parameters(x) <- value
## S4 method for signature 'starve'
time_parameters(x)
## S4 replacement method for signature 'starve'
time_parameters(x) <- value
## S4 method for signature 'starve'
dat(x)
## S4 replacement method for signature 'starve'
dat(x) <- value
## S4 method for signature 'starve'
data_predictions(x)
## S4 replacement method for signature 'starve'
data_predictions(x) <- value
## S4 method for signature 'starve'
response_distribution(x)
## S4 replacement method for signature 'starve'
response_distribution(x) <- value
## S4 method for signature 'starve'
response_parameters(x)
## S4 replacement method for signature 'starve'
response_parameters(x) <- value
## S4 method for signature 'starve'
link_function(x)
## S4 replacement method for signature 'starve'
link_function(x) <- value
## S4 method for signature 'starve'
fixed_effects(x)
## S4 replacement method for signature 'starve'
fixed_effects(x) <- value
## S4 method for signature 'starve'
distance_units(x)
## S4 replacement method for signature 'starve'
distance_units(x) <- value
## S4 method for signature 'starve'
formula(x)
## S4 replacement method for signature 'starve'
formula(x) <- value
## S4 method for signature 'starve'
parameters(x)
## S4 replacement method for signature 'starve,parameters'
parameters(x) <- value
## S4 method for signature 'starve'
convergence(x)
## S4 method for signature 'starve'
timing(x)
## S4 method for signature 'starve'
show(object)
x |
An object |
value |
A replacement value |
object |
An object |
settings(starve): Get model settings
tracing(starve): Get tracing information, see tracing.
time_effects(starve): Get temporal random effects
time_effects(starve) <- value: Set temporal random effects
pg_re(starve): Get persistent graph random effects
pg_re(starve) <- value: Set spatio-temporal random effects
tg_re(starve): Get transient graph random effects
tg_re(starve) <- value: Set transient graph random effects
random_effects(starve): Get list containing the persistent graph random
effects and the transient graph random effects.
persistent_graph(starve): Get persistent graph
transient_graph(starve): Get transient graph
graph(starve): Get a list containing the persistent and transient graphs
covariance_function(starve): Get covariance function
covariance_function(starve) <- value: Set covariance function(s). Run
get_starve_distributions("covariance") for valid covariance functions.
Setting the covariance function also overwrites the spatial parameters.
space_parameters(starve): Get spatial parameters
space_parameters(starve) <- value: Set spatial parameters
time_parameters(starve): Get time parameters
time_parameters(starve) <- value: Set time parameters
dat(starve): Get data including response variables, time indices,
locations, covariates, etc.
dat(starve) <- value: Set data. Warning: if you want to add new
rows you must give each additional row a value in the graph_idx column,
or create a new object from scratch.
data_predictions(starve): Get data predictions, a long_stars object
with the data (see dat) and associated random effect
predictions.
data_predictions(starve) <- value: Set data predictions
response_distribution(starve): Get the response distribution(s)
response_distribution(starve) <- value: Set the response distribution(s). Run
get_starve_distributions("distribution") for valid options.
Setting the response distribution also overwrites the response
parameters and link function(s).
response_parameters(starve): Get response distribution parameters
response_parameters(starve) <- value: Set response distribution parameters
link_function(starve): Get link function(s)
link_function(starve) <- value: Set link function(s). Run
get_starve_distributions("link") for valid link functions.
fixed_effects(starve): Get fixed effect parameters
fixed_effects(starve) <- value: Set fixed effect parameters
distance_units(starve): Get distance units used for the model
distance_units(starve) <- value: Set distance units used for the model
formula(starve): Get formula used for model
formula(starve) <- value: Set formula used for the model
parameters(starve): Get all model parameters as a parameters object
parameters(x = starve) <- value: Set all model parameters with a new
parameters object
convergence(starve): Get convergence message from optimizer
timing(starve): Get all timing information, see tracing
show(starve): Print method
processA process object.
observationsAn observations object.
settingsA settings object.
strv_prepare
Other starve_classes:
TMB_out-class,
dag-class,
long_stars-class,
observation_parameters-class,
observations-class,
parameters-class,
process-class,
process_parameters-class,
settings-class,
tracing-class
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.