| tracing-class | R Documentation |
An S4 class to hold optimization tracing for a starve model
## S4 method for signature 'tracing'
opt_time(x)
## S4 method for signature 'tracing'
hess_time(x)
## S4 method for signature 'tracing'
sdr_time(x)
## S4 method for signature 'tracing'
parameter_hessian(x)
## S4 method for signature 'tracing'
parameter_covariance(x)
## S4 method for signature 'tracing'
timing(x)
## S4 method for signature 'tracing'
show(object)
x |
An object |
object |
An object |
opt_time(tracing): Get optimization time
hess_time(tracing): Get hessian computation time
sdr_time(tracing): Get standard error computation time
parameter_hessian(tracing): Get parameter estimator hessian matrix
parameter_covariance(tracing): Get parameter estimator covariance matrix
timing(tracing): Get all timing information as a list with elements
fit, hessian, and sdr.
show(tracing): Print method
opt_timeA proc_time object. Time elapsed while computing the ML estimates.
hess_timeA proc_time object. Time elapsed while computing the hessian matrix.
sdr_timeA proc_time object. Time elapsed while computing standard errors.
parameter_hessianThe hessian matrix for parameter estimates.
parameter_covarianceThe covariance matrix for parameter estimates.
Other starve_classes:
TMB_out-class,
dag-class,
long_stars-class,
observation_parameters-class,
observations-class,
parameters-class,
process-class,
process_parameters-class,
settings-class,
starve-class
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.